@@ -23,10 +23,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#ifdef WITH_PCRE2
 #include "terminal-pcre2.h"
-#endif
-
 #include "terminal-search-popover.h"
 #include "terminal-intl.h"
 #include "terminal-window.h"
@@ -68,11 +65,7 @@ struct _TerminalSearchPopoverPrivate
   gboolean regex_caseless;
   gboolean regex_multiline;
   char *regex_pattern;
-#ifdef WITH_PCRE2
   VteRegex *regex;
-#else
-  GRegex *regex;
-#endif
 };
 
 enum {
@@ -283,18 +276,13 @@ update_regex (TerminalSearchPopover *popover)
     return;
 
   if (priv->regex) {
-#ifdef WITH_PCRE2
     vte_regex_unref (priv->regex);
-#else
-    g_regex_unref (priv->regex);
-#endif
   }
 
   g_clear_pointer (&priv->regex_pattern, g_free);
 
   /* FIXME: if comping the regex fails, show the error message somewhere */
   if (search_text[0] != '\0') {
-#ifdef WITH_PCRE2
     guint32 compile_flags;
 
     compile_flags = PCRE2_UTF | PCRE2_NO_UTF_CHECK;
@@ -303,22 +291,12 @@ update_regex (TerminalSearchPopover *popover)
     if (multiline)
       compile_flags |= PCRE2_MULTILINE;
 
-    priv->regex = vte_regex_new (pattern, -1, compile_flags, &error);
+    priv->regex = vte_regex_new_for_search (pattern, -1, compile_flags, &error);
     if (priv->regex != NULL &&
         (!vte_regex_jit (priv->regex, PCRE2_JIT_COMPLETE, NULL) ||
          !vte_regex_jit (priv->regex, PCRE2_JIT_PARTIAL_SOFT, NULL))) {
     }
-#else
-    GRegexCompileFlags compile_flags;
 
-    compile_flags = G_REGEX_OPTIMIZE;
-    if (caseless)
-      compile_flags |= G_REGEX_CASELESS;
-    if (multiline)
-      compile_flags |= G_REGEX_MULTILINE;
-
-    priv->regex = g_regex_new (pattern, compile_flags, 0, &error);
-#endif
     if (priv->regex != NULL)
       gs_transfer_out_value (&priv->regex_pattern, &pattern);
   } else {
@@ -431,11 +409,7 @@ terminal_search_popover_finalize (GObject *object)
   TerminalSearchPopoverPrivate *priv = PRIV (popover);
 
   if (priv->regex) {
-#ifdef WITH_PCRE2
     vte_regex_unref (priv->regex);
-#else
-    g_regex_unref (priv->regex);
-#endif
   }
 
   g_free (priv->regex_pattern);
@@ -504,11 +478,7 @@ terminal_search_popover_class_init (TerminalSearchPopoverClass *klass)
 
   pspecs[PROP_REGEX] =
     g_param_spec_boxed ("regex", NULL, NULL,
-#ifdef WITH_PCRE2
                         VTE_TYPE_REGEX,
-#else
-                        G_TYPE_REGEX,
-#endif
                         G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB);
 
   pspecs[PROP_WRAP_AROUND] =
@@ -556,11 +526,7 @@ terminal_search_popover_new (GtkWidget *relative_to_widget)
  *
  * Returns: (transfer none): the search regex, or %NULL
  */
-#ifdef WITH_PCRE2
 VteRegex *
-#else
-GRegex *
-#endif
 terminal_search_popover_get_regex (TerminalSearchPopover *popover)
 {
   g_return_val_if_fail (TERMINAL_IS_SEARCH_POPOVER (popover), NULL);
